==> phpwebthings-0.6.0.zip: phpwebthings-0.6.0/modules/news/lang/msg_enus.php <==
<?php
// lang file for news
// News
$lang["NEWS_TITLE"] = "News";
$lang["NEWS_POSTED_BY"] = "Posted by ";
$lang["NEWS_SAME_CAT"] = "more from same";
$lang["NEWS_CLICK_MORE"] = "click here for more...";
$lang["NEWS_SUBMIT_TITLE"] = "Submit news";
$lang["NEWS_EDIT_TITLE"] = "Editing news";
$lang["NEWS_PENDING_TITLE"] = "Pending news";
$lang["NEWS_DELETE_TITLE"] = "Delete";
$lang["NEWS_SUBMIT_DONE"] = "News Submited";
$lang["NEWS_SUBMIT_THANKS"] = "Your news was submited!<br><br>Thanks!";
$lang["NEWS_SUBMIT_THANKS_MAIL_TITLE"] = "A NEWS was submited at your site";
$lang["NEWS_SUBMIT_THANKS_MAIL"] = "A NEWS was added to your site, and was already activated";
$lang["NEWS_SUBMIT_THANKS2"] = "Your news was submited, but first it must be activated by the site administrator.<br><br>Thanks!";
$lang["NEWS_SUBMIT_THANKS2_MAIL"] = "A NEWS was added to your site and is waiting your activation";
$lang["NEWS_FIELD_TITLE"] = "Title:";
$lang["NEWS_FIELD_IMAGE"] = "Image:";
$lang["NEWS_FIELD_CAT"] = "Category:";
$lang["NEWS_FIELD_TEXT"] = "Text:";
$lang["NEWS_FIELD_FULL_TEXT"] = "Full text (optional):";
$lang["NEWS_FIELD_ACTIVE"] = "Published";
$lang["NEWS_FIELD_ARCHIVED"] = "Archived";
$lang["NEWS_FIELD_UID"] = "User:";
$lang["NEWS_FIELD_DATE"] = "Date:";
$lang["NEWS_FIELD_ALIGN"] = "Image align:";
$lang["NEWS_PENDING"] = "Activation pending for these news";
$lang["NEWS_PENDING_NONE"] = "There is no news pending for activation";
$lang["NEWS_PENDING_MSG"] = "There are pending news waiting for activation.";
$lang["NEWS_EDIT"] = "edit";
$lang["NEWS_ARCHIVED"] = "View archived news";
$lang["NEWS_DELETED"] = "News deleted";
$lang["NOT_LOGGED_NEWS"] = "Sorry, but you need to login to send a news. If you don't have a login, why don't you register? It's free!";
?>

==> phpwebthings-1.0.zip: phpwebthings-1.0/modules/news/lang/msg_enus.php <==
<?php
// lang file for news
// News
$lang["NEWS_TITLE"] = "News";
$lang["NEWS_POSTED_BY"] = "Posted by ";
$lang["NEWS_SAME_CAT"] = "more from same";
$lang["NEWS_CLICK_MORE"] = "click here for more...";
$lang["NEWS_SUBMIT_TITLE"] = "Submit news";
$lang["NEWS_EDIT_TITLE"] = "Editing news";
$lang["NEWS_PENDING_TITLE"] = "Pending news";
$lang["NEWS_DELETE_TITLE"] = "Delete";
$lang["NEWS_SUBMIT_DONE"] = "News Submited";
$lang["NEWS_SUBMIT_THANKS"] = "Your news was submited!<br><br>Thanks!";
$lang["NEWS_SUBMIT_THANKS_MAIL_TITLE"] = "A NEWS was submited at your site";
$lang["NEWS_SUBMIT_THANKS_MAIL"] = "A NEWS was added to your site, and was already activated";
$lang["NEWS_SUBMIT_THANKS2"] = "Your news was submited, but first it must be activated by the site administrator.<br><br>Thanks!";
$lang["NEWS_SUBMIT_THANKS2_MAIL"] = "A NEWS was added to your site and is waiting your activation";
$lang["NEWS_FIELD_TITLE"] = "Title:";
$lang["NEWS_FIELD_IMAGE"] = "Image:";
$lang["NEWS_FIELD_CAT"] = "Category:";
$lang["NEWS_FIELD_TEXT"] = "Text:";
$lang["NEWS_FIELD_FULL_TEXT"] = "Full text (optional):";
$lang["NEWS_FIELD_ACTIVE"] = "Published";
$lang["NEWS_FIELD_ARCHIVED"] = "Archived";
$lang["NEWS_FIELD_UID"] = "User:";
$lang["NEWS_FIELD_DATE"] = "Date:";
$lang["NEWS_FIELD_ALIGN"] = "Image align:";
$lang["NEWS_PENDING"] = "Activation pending for these news";
$lang["NEWS_PENDING_NONE"] = "There is no news pending for activation";
$lang["NEWS_PENDING_MSG"] = "There are pending news waiting for activation.";
$lang["NEWS_EDIT"] = "edit";
$lang["NEWS_ARCHIVED"] = "View archived news";
$lang["NEWS_DELETED"] = "News deleted";
$lang["NOT_LOGGED_NEWS"] = "Sorry, but you need to login to send a news. If you don't have a login, why don't you register? It's free!";
$lang["NEWS_CAT_EDIT"] = "News Categories";
$lang["NEWS_ARCH_TITLE"] = "Archive News";
$lang["NEWS_SEARCH"] = "Search";
$lang["NEWS_INVALID_SEARCH"] = "Invalid search parameter.";
$lang["NEWS_SEARCH_DATE"] = "Date";
$lang["NEWS_SEARCH_TITLE"] = "Title";

?>
